@@ -48,14 +48,6 @@ class PyXploraApi(PyXplora):
                     signup,
                 )
                 if self._gqlHandler:
-                    if not await self._gqlHandler.checkEmailOrPhoneExist_a(
-                        UserContactType.EMAIL if self._email else UserContactType.PHONE,
-                        email=self._email,
-                        countryCode=self._countrycode,
-                        phoneNumber=self._phoneNumber,
-                    ):
-                        self.error_message = ErrorMSG.PHONE_MAIL_ERR.value
-                        raise PhoneOrEmailFail()
                     retryCounter = 0
                     while not self._isConnected() and (retryCounter < self.maxRetries + 2):
                         retryCounter += 1
@@ -103,7 +95,9 @@ class PyXploraApi(PyXplora):
     def version(self) -> str:
         return f"{VERSION}-{VERSION_APP}"
 
-    async def setDevices(self, ids: list = []) -> list[str]:
+    async def setDevices(self, ids: str | list = None) -> list[str]:
+        if isinstance(ids, str):
+            return await self._setDevices([ids])
         return await self._setDevices(ids)
 
     async def _setDevices(self, ids: list = []) -> list[str]:
